import { useTranslation } from 'react-i18next'
import { useLanyardWS, Activity as TActivity } from 'use-lanyard';
import { DiscordWhoamiIcon, GameWhoamiIcon, SpotifyWhoamiIcon, StatusDoNotDisturb, StatusIdle, StatusOffline, StatusOnline, VscodeWhoamiIcon } from './Icons.tsx';
// import data from '../data.ts';

const colors = {
    online: StatusOnline,
    idle: StatusIdle,
    dnd: StatusDoNotDisturb,
    offline: StatusOffline,
}

const code = ['Code', 'Intellij', 'Jetbrains']

const Activity = ({ data }: { data: TActivity }) => {
    if (code.some(x => data.name.includes(x)))
        return <div className="flex flex-row">
            <div className="flex flex-col justify-center pr-4">
                <VscodeWhoamiIcon />
            </div>
            <div className="flex flex-col justify-center">
                <h1 className='text-lg font-light'>{data.name}</h1>
                {data.state && <p className='text-sm font-light text-zinc-300'>{data.state}</p>}
                {data.details && <p className='text-sm font-light text-zinc-300'>{data.details}</p>}
            </div>
        </div>

    return <div className="flex flex-row">
        <div className="flex flex-col justify-center pr-4">
            <GameWhoamiIcon />
        </div>
        <div className="flex flex-col justify-center">
            <h1 className='text-lg font-light'>{data.name}</h1>
            {data.state && <p className='text-sm font-light text-zinc-300'>{data.state}</p>}
            {data.details && <p className='text-sm font-light text-zinc-300'>{data.details}</p>}
        </div>
    </div>;
}

export const Whoami = () => {
    const { t } = useTranslation();

    const data = useLanyardWS('821421438719492136', {
        api: { hostname: 'api.lanyard.alekswilc.dev', secure: true }
    });

    const customStatus = data && data.activities.find(x => x.id === 'custom');
    const StatusActivity = data && colors[data.discord_status];

    return <div className="flex flex-col md:flex-row gap-4">
        <div className='bg-[#1C1C1C] text-white flex flex-col border-1 border-[#757575] rounded-xl text-left p-4 grow basis-3xs'>
            <h1 className='font-bold text-xl'>{t('landing.title')}</h1>
            <p className='font-light'>{t('landing.desc1')}</p>
            <p className='font-light'>{t('landing.desc2')}</p>
            <p className='font-light'>{t('landing.desc3')}</p>
        </div>

        {data && <div className='bg-[#1C1C1C] text-white flex flex-col border-1 border-[#757575] rounded-xl text-left p-4 grow basis-1'>
            <div className="flex flex-row gap-6">
                <div className="flex flex-row w-full">
                    <div className="flex-col justify-center hidden md:flex pr-6">
                        <img src="https://www.alekswilc.dev/avatar.jpg" alt="avatar" className='max-w-24 rounded-xl' />
                    </div>
                    <div className='flex flex-col justify-center'>
                        <div className="flex flex-row">
                            <h1 className='text-xl font-bold'>{data.discord_user.global_name}</h1>
                            <div className="flex flex-col justify-center pl-2">
                                {StatusActivity && <StatusActivity />}
                            </div>
                        </div>
                        {customStatus && <p className='font-extralight text-zinc-300'>{customStatus.state}</p>}
                    </div>

                    <div className="flex ml-auto mb-auto">
                        <DiscordWhoamiIcon />
                    </div>
                </div>
            </div>
            <div className='border-t-1 border-t-[#757575] w-full mt-4 mb-4' />
            {data.discord_status === 'offline' && <div className="flex flex-col justify-center text-center items-center">
                <h1>{t('landing.discord.offline')}</h1>
            </div>}
            <div className="grid grid-cols-1 md:grid-cols-2 gap-4 pl-2 pb-2 ">
                {
                    data.spotify &&
                    <div className="flex flex-row">
                        <div className="flex flex-col justify-center pr-4">
                            <SpotifyWhoamiIcon />
                        </div>
                        <div className="flex flex-col justify-center">
                            <h1 className='text-lg font-light'>{t("landing.discord.listening")}</h1>
                            <p className='text-sm font-light text-zinc-300'>{t("landing.discord.song", { song: data.spotify.song, artist: data.spotify.artist })}</p>
                        </div>
                    </div>
                }
                {
                    data.activities.filter(x => x.name !== 'Spotify' && x.id !== 'custom').sort((a, b) => a.state ? b.state ? 1 : -1 : -1).map((activity, i) =>
                        <Activity data={activity} key={i} />
                    )
                }


            </div>
        </div>}
    </div>;
}